@@ -69,7 +69,7 @@ public:
             connect(m_intervalTimer, SIGNAL(timeout()), SLOT(interval()));
             m_intervalTimer->start();
         } else {
-            m_tag = gst_bus_add_watch_full(bus, G_PRIORITY_DEFAULT, busCallback, this, NULL);
+            m_tag = gst_bus_add_watch_full(bus, G_PRIORITY_DEFAULT, busCallback, this, nullptr);
         }
     }
 
@@ -186,27 +186,27 @@ QGstreamerBusHelper::~QGstreamerBusHelper()
 
 void QGstreamerBusHelper::installMessageFilter(QObject *filter)
 {
-    QGstreamerSyncMessageFilter *syncFilter = qobject_cast<QGstreamerSyncMessageFilter*>(filter);
+    auto syncFilter = qobject_cast<QGstreamerSyncMessageFilter*>(filter);
     if (syncFilter) {
         QMutexLocker lock(&d->filterMutex);
         if (!d->syncFilters.contains(syncFilter))
             d->syncFilters.append(syncFilter);
     }
 
-    QGstreamerBusMessageFilter *busFilter = qobject_cast<QGstreamerBusMessageFilter*>(filter);
+    auto busFilter = qobject_cast<QGstreamerBusMessageFilter*>(filter);
     if (busFilter && !d->busFilters.contains(busFilter))
         d->busFilters.append(busFilter);
 }
 
 void QGstreamerBusHelper::removeMessageFilter(QObject *filter)
 {
-    QGstreamerSyncMessageFilter *syncFilter = qobject_cast<QGstreamerSyncMessageFilter*>(filter);
+    auto syncFilter = qobject_cast<QGstreamerSyncMessageFilter*>(filter);
     if (syncFilter) {
         QMutexLocker lock(&d->filterMutex);
         d->syncFilters.removeAll(syncFilter);
     }
 
-    QGstreamerBusMessageFilter *busFilter = qobject_cast<QGstreamerBusMessageFilter*>(filter);
+    auto busFilter = qobject_cast<QGstreamerBusMessageFilter*>(filter);
     if (busFilter)
         d->busFilters.removeAll(busFilter);
 }
