@@ -58,7 +58,7 @@
 #include <private/qaudiohelpers_p.h>
 #include <private/qmediaresourcepolicy_p.h>
 #include <private/qmediaresourceset_p.h>
-
+#include <QAudioDeviceInfo>
 #include <unistd.h>
 
 //#define QT_PA_DEBUG
@@ -360,6 +360,12 @@ QSoundEffectPrivate::QSoundEffectPrivate(QObject* parent):
             this, &QSoundEffectPrivate::handleAvailabilityChanged);
 }
 
+QSoundEffectPrivate::QSoundEffectPrivate(const QAudioDeviceInfo &audioDevice, QObject *parent)
+    : QSoundEffectPrivate(parent)
+{
+    m_sinkName = audioDevice.deviceName();
+}
+
 void QSoundEffectPrivate::handleAvailabilityChanged(bool available)
 {
     m_resourcesAvailable = available;
@@ -522,6 +528,21 @@ qreal QSoundEffectPrivate::volume() const
     return m_volume;
 }
 
+static void volume_stream_flush_callback(pa_stream *s, int success, void *userdata)
+{
+    Q_UNUSED(s);
+    QSoundEffectRef *ref = reinterpret_cast<QSoundEffectRef *>(userdata);
+    QSoundEffectPrivate *self = ref->soundEffect();
+    ref->release();
+    if (!self)
+        return;
+
+    if (!success)
+        qWarning("QSoundEffect(pulseaudio): failed to drain");
+
+    QMetaObject::invokeMethod(self, "prepare", Qt::QueuedConnection);
+}
+
 void QSoundEffectPrivate::setVolume(qreal volume)
 {
     QMutexLocker locker(&m_volumeLock);
@@ -531,6 +552,8 @@ void QSoundEffectPrivate::setVolume(qreal volume)
 
     m_volume = qBound(qreal(0), volume, qreal(1));
     locker.unlock();
+    if (!m_playing && m_pulseStream)
+        pa_stream_flush(m_pulseStream, volume_stream_flush_callback, m_ref->getRef());
     emit volumeChanged();
 }
 
@@ -1005,8 +1028,9 @@ void QSoundEffectPrivate::createPulseStream()
     }
     m_pulseStream = stream;
 
-    if (pa_stream_connect_playback(m_pulseStream, nullptr, nullptr,
-                                   PA_STREAM_START_CORKED, nullptr, nullptr) < 0) {
+    if (pa_stream_connect_playback(m_pulseStream,
+                                   m_sinkName.isEmpty() ? nullptr : m_sinkName.toLatin1().constData(),
+                                   nullptr, PA_STREAM_START_CORKED, nullptr, nullptr) < 0) {
         qWarning("QSoundEffect(pulseaudio): Failed to connect stream, error = %s",
                  pa_strerror(pa_context_errno(pulseDaemon()->context())));
     }
