@@ -38,6 +38,7 @@
 ****************************************************************************/
 
 #include "qmediaplayer.h"
+#include "qvideosurfaces_p.h"
 #include "qvideosurfaceoutput_p.h"
 
 #include "qmediaobject_p.h"
@@ -58,6 +59,7 @@
 #include <QtCore/qpointer.h>
 #include <QtCore/qfileinfo.h>
 #include <QtCore/qtemporaryfile.h>
+#include <QDir>
 
 QT_BEGIN_NAMESPACE
 
@@ -109,12 +111,14 @@ class QMediaPlayerPrivate : public QMediaObjectPrivate
 
 public:
     QMediaPlayerPrivate()
-        : provider(0)
-        , control(0)
-        , audioRoleControl(0)
-        , customAudioRoleControl(0)
-        , playlist(0)
-        , networkAccessControl(0)
+        : provider(nullptr)
+        , control(nullptr)
+        , audioRoleControl(nullptr)
+        , customAudioRoleControl(nullptr)
+        , playlist(nullptr)
+#ifndef QT_NO_BEARERMANAGEMENT
+        , networkAccessControl(nullptr)
+#endif
         , state(QMediaPlayer::StoppedState)
         , status(QMediaPlayer::UnknownMediaStatus)
         , error(QMediaPlayer::NoError)
@@ -131,7 +135,12 @@ public:
 
     QPointer<QObject> videoOutput;
     QMediaPlaylist *playlist;
+#ifndef QT_NO_BEARERMANAGEMENT
+QT_WARNING_PUSH
+QT_WARNING_DISABLE_DEPRECATED
     QMediaNetworkAccessControl *networkAccessControl;
+QT_WARNING_POP
+#endif
     QVideoSurfaceOutput surfaceOutput;
     QMediaContent qrcMedia;
     QScopedPointer<QFile> qrcFile;
@@ -148,7 +157,7 @@ public:
     QMediaPlaylist *parentPlaylist(QMediaPlaylist *pls);
     bool isInChain(const QUrl &url);
 
-    void setMedia(const QMediaContent &media, QIODevice *stream = 0);
+    void setMedia(const QMediaContent &media, QIODevice *stream = nullptr);
 
     void setPlaylist(QMediaPlaylist *playlist);
     void setPlaylistMedia();
@@ -175,7 +184,7 @@ QMediaPlaylist *QMediaPlayerPrivate::parentPlaylist(QMediaPlaylist *pls)
     for (QMediaPlaylist *current = rootMedia.playlist(); current && current != pls; current = current->currentMedia().playlist())
         if (current->currentMedia().playlist() == pls)
             return current;
-    return 0;
+    return nullptr;
 }
 
 bool QMediaPlayerPrivate::isInChain(const QUrl &url)
@@ -183,7 +192,7 @@ bool QMediaPlayerPrivate::isInChain(const QUrl &url)
     // Check whether a URL is already in the chain of playlists.
     // Also see a comment in parentPlaylist().
     for (QMediaPlaylist *current = rootMedia.playlist(); current && current != playlist; current = current->currentMedia().playlist())
-        if (current->currentMedia().canonicalUrl() == url) {
+        if (current->currentMedia().request().url() == url) {
             return true;
         }
     return false;
@@ -309,7 +318,7 @@ void QMediaPlayerPrivate::_q_updateMedia(const QMediaContent &media)
 
     const QMediaPlayer::State currentState = state;
 
-    setMedia(media, 0);
+    setMedia(media, nullptr);
 
     if (!media.isNull()) {
         switch (currentState) {
@@ -329,8 +338,8 @@ void QMediaPlayerPrivate::_q_updateMedia(const QMediaContent &media)
 
 void QMediaPlayerPrivate::_q_playlistDestroyed()
 {
-    playlist = 0;
-    setMedia(QMediaContent(), 0);
+    playlist = nullptr;
+    setMedia(QMediaContent(), nullptr);
 }
 
 void QMediaPlayerPrivate::setMedia(const QMediaContent &media, QIODevice *stream)
@@ -345,10 +354,10 @@ void QMediaPlayerPrivate::setMedia(const QMediaContent &media, QIODevice *stream
     // Backends can't play qrc files directly.
     // If the backend supports StreamPlayback, we pass a QFile for that resource.
     // If it doesn't, we copy the data to a temporary file and pass its path.
-    if (!media.isNull() && !stream && media.canonicalUrl().scheme() == QLatin1String("qrc")) {
+    if (!media.isNull() && !stream && media.request().url().scheme() == QLatin1String("qrc")) {
         qrcMedia = media;
 
-        file.reset(new QFile(QLatin1Char(':') + media.canonicalUrl().path()));
+        file.reset(new QFile(QLatin1Char(':') + media.request().url().path()));
         if (!file->open(QFile::ReadOnly)) {
             QMetaObject::invokeMethod(q, "_q_error", Qt::QueuedConnection,
                                       Q_ARG(int, QMediaPlayer::ResourceError),
@@ -360,12 +369,19 @@ void QMediaPlayerPrivate::setMedia(const QMediaContent &media, QIODevice *stream
             // on the backend side since we can't load the new one and we want to be in the
             // InvalidMedia status.
             ignoreNextStatusChange = QMediaPlayer::NoMedia;
-            control->setMedia(QMediaContent(), 0);
+            control->setMedia(QMediaContent(), nullptr);
 
         } else if (hasStreamPlaybackFeature) {
             control->setMedia(media, file.data());
         } else {
 #if QT_CONFIG(temporaryfile)
+#if defined(Q_OS_ANDROID)
+            QString tempFileName = QDir::tempPath() + media.request().url().path();
+            QDir().mkpath(QFileInfo(tempFileName).path());
+            QTemporaryFile *tempFile = QTemporaryFile::createNativeFile(*file);
+            if (!tempFile->rename(tempFileName))
+                qWarning() << "Could not rename temporary file to:" << tempFileName;
+#else
             QTemporaryFile *tempFile = new QTemporaryFile;
 
             // Preserve original file extension, some backends might not load the file if it doesn't
@@ -384,9 +400,9 @@ void QMediaPlayerPrivate::setMedia(const QMediaContent &media, QIODevice *stream
                 tempFile->write(buffer, len);
             }
             tempFile->close();
-
+#endif
             file.reset(tempFile);
-            control->setMedia(QMediaContent(QUrl::fromLocalFile(file->fileName())), 0);
+            control->setMedia(QMediaContent(QUrl::fromLocalFile(file->fileName())), nullptr);
 #else
             qWarning("Qt was built with -no-feature-temporaryfile: playback from resource file is not supported!");
 #endif
@@ -447,13 +463,13 @@ void QMediaPlayerPrivate::setPlaylistMedia()
             //                      media is not changed,
             //                      frontend needs to emit currentMediaChanged
             bool isSameMedia = (q->currentMedia() == playlist->currentMedia());
-            setMedia(playlist->currentMedia(), 0);
+            setMedia(playlist->currentMedia(), nullptr);
             if (isSameMedia) {
                 emit q->currentMediaChanged(q->currentMedia());
             }
         }
     } else {
-        setMedia(QMediaContent(), 0);
+        setMedia(QMediaContent(), nullptr);
     }
 }
 
@@ -464,11 +480,14 @@ void QMediaPlayerPrivate::loadPlaylist()
 
     // Do not load a playlist if there are more than MAX_NESTED_PLAYLISTS in the chain already,
     // or if the playlist URL is already in the chain, i.e. do not allow recursive playlists and loops.
-    if (nestedPlaylists < MAX_NESTED_PLAYLISTS && !q->currentMedia().canonicalUrl().isEmpty() && !isInChain(q->currentMedia().canonicalUrl())) {
-        pendingPlaylist = QMediaContent(new QMediaPlaylist, q->currentMedia().canonicalUrl(), true);
+    if (nestedPlaylists < MAX_NESTED_PLAYLISTS
+        && !q->currentMedia().request().url().isEmpty()
+        && !isInChain(q->currentMedia().request().url()))
+    {
+        pendingPlaylist = QMediaContent(new QMediaPlaylist, q->currentMedia().request().url(), true);
         QObject::connect(pendingPlaylist.playlist(), SIGNAL(loaded()), q, SLOT(_q_handlePlaylistLoaded()));
         QObject::connect(pendingPlaylist.playlist(), SIGNAL(loadFailed()), q, SLOT(_q_handlePlaylistLoadFailed()));
-        pendingPlaylist.playlist()->load(pendingPlaylist.canonicalRequest());
+        pendingPlaylist.playlist()->load(pendingPlaylist.request());
     } else if (playlist) {
         playlist->next();
     }
@@ -545,14 +564,14 @@ void QMediaPlayerPrivate::_q_handlePlaylistLoadFailed()
     if (playlist)
         playlist->next();
     else
-        setMedia(QMediaContent(), 0);
+        setMedia(QMediaContent(), nullptr);
 }
 
 static QMediaService *playerService(QMediaPlayer::Flags flags)
 {
     QMediaServiceProvider *provider = QMediaServiceProvider::defaultServiceProvider();
     if (flags) {
-        QMediaServiceProviderHint::Features features = 0;
+        QMediaServiceProviderHint::Features features;
         if (flags & QMediaPlayer::LowLatency)
             features |= QMediaServiceProviderHint::LowLatencyPlayback;
 
@@ -583,27 +602,32 @@ QMediaPlayer::QMediaPlayer(QObject *parent, QMediaPlayer::Flags flags):
     Q_D(QMediaPlayer);
 
     d->provider = QMediaServiceProvider::defaultServiceProvider();
-    if (d->service == 0) {
+    if (d->service == nullptr) {
         d->error = ServiceMissingError;
     } else {
         d->control = qobject_cast<QMediaPlayerControl*>(d->service->requestControl(QMediaPlayerControl_iid));
+#ifndef QT_NO_BEARERMANAGEMENT
+QT_WARNING_PUSH
+QT_WARNING_DISABLE_DEPRECATED
         d->networkAccessControl = qobject_cast<QMediaNetworkAccessControl*>(d->service->requestControl(QMediaNetworkAccessControl_iid));
-        if (d->control != 0) {
+QT_WARNING_POP
+#endif
+        if (d->control != nullptr) {
             connect(d->control, SIGNAL(mediaChanged(QMediaContent)), SLOT(_q_handleMediaChanged(QMediaContent)));
             connect(d->control, SIGNAL(stateChanged(QMediaPlayer::State)), SLOT(_q_stateChanged(QMediaPlayer::State)));
             connect(d->control, SIGNAL(mediaStatusChanged(QMediaPlayer::MediaStatus)),
                     SLOT(_q_mediaStatusChanged(QMediaPlayer::MediaStatus)));
             connect(d->control, SIGNAL(error(int,QString)), SLOT(_q_error(int,QString)));
 
-            connect(d->control, SIGNAL(durationChanged(qint64)), SIGNAL(durationChanged(qint64)));
-            connect(d->control, SIGNAL(positionChanged(qint64)), SIGNAL(positionChanged(qint64)));
-            connect(d->control, SIGNAL(audioAvailableChanged(bool)), SIGNAL(audioAvailableChanged(bool)));
-            connect(d->control, SIGNAL(videoAvailableChanged(bool)), SIGNAL(videoAvailableChanged(bool)));
-            connect(d->control, SIGNAL(volumeChanged(int)), SIGNAL(volumeChanged(int)));
-            connect(d->control, SIGNAL(mutedChanged(bool)), SIGNAL(mutedChanged(bool)));
-            connect(d->control, SIGNAL(seekableChanged(bool)), SIGNAL(seekableChanged(bool)));
-            connect(d->control, SIGNAL(playbackRateChanged(qreal)), SIGNAL(playbackRateChanged(qreal)));
-            connect(d->control, SIGNAL(bufferStatusChanged(int)), SIGNAL(bufferStatusChanged(int)));
+            connect(d->control, &QMediaPlayerControl::durationChanged, this, &QMediaPlayer::durationChanged);
+            connect(d->control, &QMediaPlayerControl::positionChanged, this, &QMediaPlayer::positionChanged);
+            connect(d->control, &QMediaPlayerControl::audioAvailableChanged, this, &QMediaPlayer::audioAvailableChanged);
+            connect(d->control, &QMediaPlayerControl::videoAvailableChanged, this, &QMediaPlayer::videoAvailableChanged);
+            connect(d->control, &QMediaPlayerControl::volumeChanged, this, &QMediaPlayer::volumeChanged);
+            connect(d->control, &QMediaPlayerControl::mutedChanged, this, &QMediaPlayer::mutedChanged);
+            connect(d->control, &QMediaPlayerControl::seekableChanged, this, &QMediaPlayer::seekableChanged);
+            connect(d->control, &QMediaPlayerControl::playbackRateChanged, this, &QMediaPlayer::playbackRateChanged);
+            connect(d->control, &QMediaPlayerControl::bufferStatusChanged, this, &QMediaPlayer::bufferStatusChanged);
 
             d->state = d->control->state();
             d->status = d->control->mediaStatus();
@@ -631,10 +655,15 @@ QMediaPlayer::QMediaPlayer(QObject *parent, QMediaPlayer::Flags flags):
                 }
             }
         }
-        if (d->networkAccessControl != 0) {
-            connect(d->networkAccessControl, SIGNAL(configurationChanged(QNetworkConfiguration)),
-            this, SIGNAL(networkConfigurationChanged(QNetworkConfiguration)));
+#ifndef QT_NO_BEARERMANAGEMENT
+        if (d->networkAccessControl != nullptr) {
+QT_WARNING_PUSH
+QT_WARNING_DISABLE_DEPRECATED
+            connect(d->networkAccessControl, &QMediaNetworkAccessControl::configurationChanged,
+                    this, &QMediaPlayer::networkConfigurationChanged);
+QT_WARNING_POP
         }
+#endif
     }
 }
 
@@ -688,7 +717,7 @@ const QIODevice *QMediaPlayer::mediaStream() const
     if (d->control && d->qrcMedia.isNull())
         return d->control->mediaStream();
 
-    return 0;
+    return nullptr;
 }
 
 QMediaPlaylist *QMediaPlayer::playlist() const
@@ -719,7 +748,12 @@ void QMediaPlayer::setPlaylist(QMediaPlaylist *playlist)
     setMedia(m);
 }
 
+#ifndef QT_NO_BEARERMANAGEMENT
+QT_WARNING_PUSH
+QT_WARNING_DISABLE_DEPRECATED
 /*!
+    \obsolete
+
     Sets the network access points for remote media playback.
     \a configurations contains, in ascending preferential order, a list of
     configuration  that can be used for network access.
@@ -733,6 +767,8 @@ void QMediaPlayer::setNetworkConfigurations(const QList<QNetworkConfiguration> &
     if (d->networkAccessControl)
         d->networkAccessControl->setConfigurations(configurations);
 }
+QT_WARNING_POP
+#endif
 
 QMediaPlayer::State QMediaPlayer::state() const
 {
@@ -740,7 +776,7 @@ QMediaPlayer::State QMediaPlayer::state() const
 
     // In case if EndOfMedia status is already received
     // but state is not.
-    if (d->control != 0
+    if (d->control != nullptr
         && d->status == QMediaPlayer::EndOfMedia
         && d->state != d->control->state()) {
         return d->control->state();
@@ -758,7 +794,7 @@ qint64 QMediaPlayer::duration() const
 {
     Q_D(const QMediaPlayer);
 
-    if (d->control != 0)
+    if (d->control != nullptr)
         return d->control->duration();
 
     return -1;
@@ -768,7 +804,7 @@ qint64 QMediaPlayer::position() const
 {
     Q_D(const QMediaPlayer);
 
-    if (d->control != 0)
+    if (d->control != nullptr)
         return d->control->position();
 
     return 0;
@@ -778,7 +814,7 @@ int QMediaPlayer::volume() const
 {
     Q_D(const QMediaPlayer);
 
-    if (d->control != 0)
+    if (d->control != nullptr)
         return d->control->volume();
 
     return 0;
@@ -788,7 +824,7 @@ bool QMediaPlayer::isMuted() const
 {
     Q_D(const QMediaPlayer);
 
-    if (d->control != 0)
+    if (d->control != nullptr)
         return d->control->isMuted();
 
     return false;
@@ -798,7 +834,7 @@ int QMediaPlayer::bufferStatus() const
 {
     Q_D(const QMediaPlayer);
 
-    if (d->control != 0)
+    if (d->control != nullptr)
         return d->control->bufferStatus();
 
     return 0;
@@ -808,7 +844,7 @@ bool QMediaPlayer::isAudioAvailable() const
 {
     Q_D(const QMediaPlayer);
 
-    if (d->control != 0)
+    if (d->control != nullptr)
         return d->control->isAudioAvailable();
 
     return false;
@@ -818,7 +854,7 @@ bool QMediaPlayer::isVideoAvailable() const
 {
     Q_D(const QMediaPlayer);
 
-    if (d->control != 0)
+    if (d->control != nullptr)
         return d->control->isVideoAvailable();
 
     return false;
@@ -828,7 +864,7 @@ bool QMediaPlayer::isSeekable() const
 {
     Q_D(const QMediaPlayer);
 
-    if (d->control != 0)
+    if (d->control != nullptr)
         return d->control->isSeekable();
 
     return false;
@@ -838,7 +874,7 @@ qreal QMediaPlayer::playbackRate() const
 {
     Q_D(const QMediaPlayer);
 
-    if (d->control != 0)
+    if (d->control != nullptr)
         return d->control->playbackRate();
 
     return 0.0;
@@ -858,7 +894,12 @@ QString QMediaPlayer::errorString() const
     return d_func()->errorString;
 }
 
+#ifndef QT_NO_BEARERMANAGEMENT
+QT_WARNING_PUSH
+QT_WARNING_DISABLE_DEPRECATED
 /*!
+    \obsolete
+
     Returns the current network access point  in use.
     If a default contructed QNetworkConfiguration is returned
     this feature is not available or that none of the
@@ -873,6 +914,8 @@ QNetworkConfiguration QMediaPlayer::currentNetworkConfiguration() const
 
     return QNetworkConfiguration();
 }
+QT_WARNING_POP
+#endif
 
 //public Q_SLOTS:
 /*!
@@ -883,7 +926,7 @@ void QMediaPlayer::play()
 {
     Q_D(QMediaPlayer);
 
-    if (d->control == 0) {
+    if (d->control == nullptr) {
         QMetaObject::invokeMethod(this, "_q_error", Qt::QueuedConnection,
                                     Q_ARG(int, QMediaPlayer::ServiceMissingError),
                                     Q_ARG(QString, tr("The QMediaPlayer object does not have a valid service")));
@@ -921,7 +964,7 @@ void QMediaPlayer::pause()
 {
     Q_D(QMediaPlayer);
 
-    if (d->control != 0)
+    if (d->control != nullptr)
         d->control->pause();
 }
 
@@ -933,7 +976,7 @@ void QMediaPlayer::stop()
 {
     Q_D(QMediaPlayer);
 
-    if (d->control != 0)
+    if (d->control != nullptr)
         d->control->stop();
 
     // If media player didn't stop in response to control.
@@ -952,7 +995,7 @@ void QMediaPlayer::setPosition(qint64 position)
 {
     Q_D(QMediaPlayer);
 
-    if (d->control == 0)
+    if (d->control == nullptr)
         return;
 
     d->control->setPosition(qMax(position, 0ll));
@@ -962,7 +1005,7 @@ void QMediaPlayer::setVolume(int v)
 {
     Q_D(QMediaPlayer);
 
-    if (d->control == 0)
+    if (d->control == nullptr)
         return;
 
     int clamped = qBound(0, v, 100);
@@ -976,7 +1019,7 @@ void QMediaPlayer::setMuted(bool muted)
 {
     Q_D(QMediaPlayer);
 
-    if (d->control == 0 || muted == isMuted())
+    if (d->control == nullptr || muted == isMuted())
         return;
 
     d->control->setMuted(muted);
@@ -986,7 +1029,7 @@ void QMediaPlayer::setPlaybackRate(qreal rate)
 {
     Q_D(QMediaPlayer);
 
-    if (d->control != 0)
+    if (d->control != nullptr)
         d->control->setPlaybackRate(rate);
 }
 
@@ -994,8 +1037,9 @@ void QMediaPlayer::setPlaybackRate(qreal rate)
     Sets the current \a media source.
 
     If a \a stream is supplied; media data will be read from it instead of resolving the media
-    source. In this case the media source may still be used to resolve additional information
+    source. In this case the url should be provided to resolve additional information
     about the media such as mime type. The \a stream must be open and readable.
+    For macOS the \a stream should be also seekable.
 
     Setting the media to a null QMediaContent will cause the player to discard all
     information relating to the current media source and to cease all I/O operations related
@@ -1011,8 +1055,17 @@ void QMediaPlayer::setPlaybackRate(qreal rate)
 
     \snippet multimedia-snippets/media.cpp Pipeline
 
-    If the pipeline contains a video sink element named \c qtvideosink,
-    current QVideoWidget can be used to render the video.
+    If QAbstractVideoSurface is used as the video output,
+    \c qtvideosink can be used as a video sink element directly in the pipeline.
+    After that the surface will receive the video frames in QAbstractVideoSurface::present().
+
+    \snippet multimedia-snippets/media.cpp Pipeline Surface
+
+    If QVideoWidget is used as the video output
+    and the pipeline contains a video sink element named \c qtvideosink,
+    current QVideoWidget will be used to render the video.
+
+    \snippet multimedia-snippets/media.cpp Pipeline Widget
 
     If the pipeline contains appsrc element, it will be used to push data from \a stream.
 
@@ -1026,7 +1079,7 @@ void QMediaPlayer::setMedia(const QMediaContent &media, QIODevice *stream)
 
     QMediaContent oldMedia = d->rootMedia;
     d->disconnectPlaylist();
-    d->playlist = 0;
+    d->playlist = nullptr;
     d->rootMedia = media;
     d->nestedPlaylists = 0;
 
@@ -1112,7 +1165,7 @@ void QMediaPlayer::setVideoOutput(QVideoWidget *output)
     // We don't know (in this library) that QVideoWidget inherits QObject
     QObject *outputObject = reinterpret_cast<QObject*>(output);
 
-    d->videoOutput = outputObject && bind(outputObject) ? outputObject : 0;
+    d->videoOutput = outputObject && bind(outputObject) ? outputObject : nullptr;
 }
 
 /*!
@@ -1134,7 +1187,7 @@ void QMediaPlayer::setVideoOutput(QGraphicsVideoItem *output)
     // but QObject inheritance depends on QObject coming first, so try this out.
     QObject *outputObject = reinterpret_cast<QObject*>(output);
 
-    d->videoOutput = outputObject && bind(outputObject) ? outputObject : 0;
+    d->videoOutput = outputObject && bind(outputObject) ? outputObject : nullptr;
 }
 
 /*!
@@ -1154,17 +1207,35 @@ void QMediaPlayer::setVideoOutput(QAbstractVideoSurface *surface)
         if (d->videoOutput)
             unbind(d->videoOutput);
 
-        d->videoOutput = 0;
+        d->videoOutput = nullptr;
 
         if (surface && bind(&d->surfaceOutput))
             d->videoOutput =  &d->surfaceOutput;
     }  else if (!surface) {
         //unbind the surfaceOutput if null surface is set
         unbind(&d->surfaceOutput);
-        d->videoOutput = 0;
+        d->videoOutput = nullptr;
     }
 }
 
+/*!
+    \since 5.15
+    Sets multiple video surfaces as the video output of a media player.
+    This allows the media player to render video frames on different surfaces.
+
+    All video surfaces must support at least one shared \c QVideoFrame::PixelFormat.
+
+    If a video output has already been set on the media player the new surfaces
+    will replace it.
+
+    \sa QAbstractVideoSurface::supportedPixelFormats
+*/
+
+void QMediaPlayer::setVideoOutput(const QVector<QAbstractVideoSurface *> &surfaces)
+{
+    setVideoOutput(!surfaces.empty() ? new QVideoSurfaces(surfaces, this) : nullptr);
+}
+
 /*! \reimp */
 QMultimedia::AvailabilityStatus QMediaPlayer::availability() const
 {
@@ -1180,7 +1251,7 @@ QAudio::Role QMediaPlayer::audioRole() const
 {
     Q_D(const QMediaPlayer);
 
-    if (d->audioRoleControl != NULL)
+    if (d->audioRoleControl != nullptr)
         return d->audioRoleControl->audioRole();
 
     return QAudio::UnknownRole;
@@ -1539,7 +1610,7 @@ QStringList QMediaPlayer::supportedCustomAudioRoles() const
     This value is a multiplier applied to the media's standard play rate. By
     default this value is 1.0, indicating that the media is playing at the
     standard pace. Values higher than 1.0 will increase the rate of play.
-    Values less than zero can be set and indicate the media will rewind at the
+    Values less than zero can be set and indicate the media should rewind at the
     multiplier of the standard pace.
 
     Not all playback services support change of the playback rate. It is
@@ -1624,6 +1695,7 @@ QStringList QMediaPlayer::supportedCustomAudioRoles() const
 
 /*!
    \fn void QMediaPlayer::networkConfigurationChanged(const QNetworkConfiguration &configuration)
+   \obsolete
 
     Signal that the active in use network access point  has been changed to \a configuration and all subsequent network access will use this \a configuration.
 */
@@ -1643,6 +1715,6 @@ QStringList QMediaPlayer::supportedCustomAudioRoles() const
             QAbstractVideoSurface \l {setVideoOutput()}{output}.
 */
 
-#include "moc_qmediaplayer.cpp"
 QT_END_NAMESPACE
 
+#include "moc_qmediaplayer.cpp"
